@@ -6,6 +6,7 @@
 import os
 import sys
 import re
+import atexit
 import shutil
 import subprocess
 from datetime import datetime
@@ -38,13 +39,13 @@ class Petalinux(Basebuild):
     kernel_dir = f"{meta_user}/recipes-kernel/linux/linux-xlnx"
     kernel_bbappend = f"{meta_user}/recipes-kernel/linux/linux-xlnx_%.bbappend"
     devicetree_append = f"{devicetree_dir}/device-tree.bbappend"
-    fsbl_bbappend = f"{fsbl_dir}/fsbl_%.bbappend"
+    fsbl_bbappend = f"{fsbl_dir}/fsbl-firmware_%.bbappend"
     atf_dir = f"{recipes_bsp}/arm-trusted-firmware"
     atf_bbappend = f"{atf_dir}/arm-trusted-firmware_%.bbappend"
     uboot_dir = f"{meta_user}/recipes-bsp/u-boot"
     uboot_bbappend = f"{uboot_dir}/u-boot-xlnx_%.bbappend"
     pmufw_bbappend = f"{pmufw_dir}/pmu-firmware_%.bbappend"
-    plm_bbappend = f"{plm_dir}/plm_%.bbappend"
+    plm_bbappend = f"{plm_dir}/plm-firmware_%.bbappend"
     psmfw_bbappend = f"{psmfw_dir}/psm-firmware_%.bbappend"
     openamp_dir = f"{meta_user}/recipes-openamp"
     libmetal_dir = openamp_dir
@@ -92,6 +93,7 @@ class Petalinux(Basebuild):
         self.qemu_boot = False
         # Acquire bash console.
         self.runner = Xexpect(log, exit_nzero_ret=True)
+        atexit.register(self.__del__)
         myconfs = [
             "RECIPE_NAME",
             "RECIPE_NEW_NAME",
@@ -153,6 +155,8 @@ class Petalinux(Basebuild):
         self.runner.runcmd(cmd=str(cmd), timeout=timeout)
         self.runner.runcmd(f"cd {self.plnx_proj}")
         os.chdir(self.proj_dir)
+        if self.config.get("plnx_init_cmds"):
+            self.runner.runcmd_list(self.config.plnx_init_cmds)
 
     def fetch_project(self):
         """This Function clones petalinux project from git,
@@ -170,7 +174,6 @@ class Petalinux(Basebuild):
             if "git.bsp.branch" not in self.config:
                 self.config.git.bsp.branch = "master"
             clone(
-                self.config,
                 self.config.git.bsp,
                 self.proj_dir,
                 recurse_submodules=self.config.git.bsp.recurse_submodules,
@@ -236,11 +239,15 @@ class Petalinux(Basebuild):
         """
 
         if self.plnx_tmp:
-            self.plnx_tmp = os.path.join(
-                self.plnx_tmp,
-                self.plnx_proj + "-" + datetime.now().strftime("%Y.%m.%d-%H.%M.%S"),
+            tmp_dir = (
+                self.plnx_proj + "-" + datetime.now().strftime("%Y.%m.%d-%H.%M.%S")
             )
 
+            if os.getenv("JOB_NAME"):
+                tmp_dir = f"{os.getenv('JOB_NAME')}/{tmp_dir}"
+
+            self.plnx_tmp = os.path.join(self.plnx_tmp, tmp_dir)
+
             mkdir(self.plnx_tmp)
             os.chmod(self.plnx_tmp, 0o777)
             add_newline(
@@ -272,6 +279,7 @@ class Petalinux(Basebuild):
 
     def get_hwdesign(self, timeout: int = 600) -> None:
         """This Function apply hardware design file(.xsa) on petalinux project
+
         Parameter:
             hw_design_path : .xsa file path
         """
@@ -296,13 +304,6 @@ class Petalinux(Basebuild):
     def set_config(self):
         """This Function apply the user configs on petalinux project
 
-        Parameter:
-            plnx_configs : it is a dictionary
-        >>> rootfs  - Update/Add rootfs configs
-            project - Update/Add plnx project configs
-            kernel  - Update/Add kernel configs
-            bspconf - Update/Add local.conf configs
-
         >>> Usage:
             plnx_configs = { rootfs :   [ 'CONFIG_xen=y',
                                           'CONFIG_open-amp_demo is not set' ],
@@ -313,40 +314,45 @@ class Petalinux(Basebuild):
                            }
         """
 
+        component_map = {
+            "user-rootfs": {"conf": f"{self.user_rootfs_config}"},
+            "rootfs": {"conf": f"{self.rootfs_config}"},
+            "project": {"conf": f"{self.project_config}"},
+            "kernel": {
+                "conf": f"{self.kernel_dir}/bsp.cfg",
+                "conf_dir": f"{self.kernel_dir}",
+                "bbappend": [
+                    'FILESEXTRAPATHS_prepend := "${THISDIR}/${PN}:"',
+                    'SRC_URI += "file://bsp.cfg"',
+                ],
+            },
+            "uboot": {
+                "conf": f"{self.uboot_dir}/files/bsp.cfg",
+                "conf_dir": f"{self.uboot_dir}",
+                "bbappend": ['SRC_URI += "file://bsp.cfg"'],
+            },
+            "bspconf": {"conf": f"{self.plnxbspconf_file}"},
+        }
+
+        components = ("plm", "pmufw", "fsbl", "psmfw")
+
         for key, value in self.config["plnx_configs"].items():
             value = convert_list(value)
-            components = ("plm", "pmufw", "fsbl", "psmfw")
-            if "user-rootfs" in key:
+            if key in component_map:
+                if "conf_dir" in component_map[key].keys():
+                    mkdir(str(component_map[key]["conf_dir"]))
+                if "bbappend" in component_map[key].keys():
+                    append_list = convert_list(component_map[key]["bbappend"])
+                    for val in append_list:
+                        add_newline(getattr(self, f"{key}_bbappend"), str(val))
                 for itr in value:
                     itr = parse_config(self.config, itr)
-                    add_newline(f"{self.user_rootfs_config}", str(itr))
-            elif "rootfs" in key:
-                for itr in value:
-                    itr = parse_config(self.config, itr)
-                    add_newline(f"{self.rootfs_config}", itr)
-            elif "project" in key:
-                for itr in value:
-                    itr = parse_config(self.config, itr)
-                    add_newline(f"{self.project_config}", str(itr))
-            elif "kernel" in key:
-                mkdir(self.kernel_dir)
-                add_newline(f"{self.kernel_bbappend}", 'SRC_URI += "file://bsp.cfg"')
-                add_newline(
-                    f"{self.kernel_bbappend}",
-                    'FILESEXTRAPATHS_prepend := "${THISDIR}/${PN}:"',
-                )
-                for itr in value:
-                    itr = parse_config(self.config, itr)
-                    add_newline(f"{self.kernel_dir}/bsp.cfg", str(itr))
+                    add_newline(str(component_map[key]["conf"]), str(itr))
             elif key in components:
                 mkdir(getattr(self, f"{key}_dir"))
                 for itr in value:
                     itr = parse_config(self.config, itr)
                     add_newline(getattr(self, f"{key}_bbappend"), str(itr))
-            elif "bspconf" in key:
-                for itr in value:
-                    itr = parse_config(self.config, itr)
-                    add_newline(f"{self.plnxbspconf_file}", str(itr))
             else:
                 err_msg = f"Invalid arg {key} in plnx_configs"
                 assert False, err_msg
@@ -391,6 +397,7 @@ class Petalinux(Basebuild):
     def apply_external_component(self):
         """This function adds support to apply external src on petalinux project
             for kernel, uboot, atf, fsbl, xen, openamp components
+
         Parameters:
             url - component git url
             externalsrc - local src path
@@ -487,7 +494,17 @@ class Petalinux(Basebuild):
                     add_newline(
                         bbappend, f'EXTERNALSRC_BUILD = "{self.workDir}/{repo_name}"'
                     )
+                    if value["checksum"]:
+                        add_newline(
+                            bbappend,
+                            f"LIC_FILES_CHKSUM = \"file://license.txt;md5={value['checksum']}\"",
+                        )
                 elif value["url"]:
+                    if value["checksum"]:
+                        add_newline(
+                            bbappend,
+                            f"LIC_FILES_CHKSUM = \"file://license.txt;md5={value['checksum']}\"",
+                        )
                     add_newline(bbappend, f"REPO = \"{value['url']};protocol=https\"")
                     if value["srcrev"]:
                         if value["srcrev"] == "AUTOREV":
@@ -509,6 +526,7 @@ class Petalinux(Basebuild):
 
         Parameter:
             plnx_user_dtsi_files : user .dtsi file
+
         >>> Usage:
             plnx_user_dtsi_files = ['<path to dtsi file>']
         """
@@ -532,6 +550,7 @@ class Petalinux(Basebuild):
 
         Parameter:
            plnx_user_dtsi_file : user .dtsi file
+
         >>> Usage:
             plnx_user_dtsi_file = 'path to user dtsi file'
         """
@@ -653,7 +672,7 @@ class Petalinux(Basebuild):
             log.info(f"Checking petalinux artifacts in {self.proj_dir}")
             if "plnx_artifacts" in self.config:
                 for image in self.config["plnx_artifacts"]:
-                    image_file = find_file(image, self.workDir)
+                    image_file = find_file(image, f"{self.proj_dir}/images/linux")
                     if image_file:
                         if is_file(image_file):
                             copy_file(image_file, deploy_dir)
@@ -766,10 +785,12 @@ class Petalinux(Basebuild):
 
         """
         if self.config.get("skip_clean_temp"):
-            log.info("INFO: Skipped petaliux project temp clean...")
+            log.info("Skipped petaliux project temp clean...")
         else:
             if self.plnx_tmp:
-                log.info("INFO: Petaliunx project temp clean successful...")
+                log.info(
+                    f"Petaliunx project temp clean successful on path : {self.plnx_tmp} ..."
+                )
                 remove(self.plnx_tmp)
 
         if self.qemu_boot:
