@@ -6,8 +6,8 @@
 from roast.machines.zynqmp import *
 
 dtb_dtg = "zcu208-reva"
-silicon = "zu48dr-es1"
+silicon = "zu48dr-prod"
 uboot_devicetree = "zynqmp-zcu208-revA"
 
-PLNX_BSP = "xilinx-zcu208-es1-v{version}-final.bsp"
-plnx_proj = "xilinx-zcu208-es1-{version}"
+PLNX_BSP = "xilinx-zcu208-v{version}-final.bsp"
+plnx_proj = "xilinx-zcu208-{version}"
